# pygitscrum

## Description

With pygitscrum you can masterize few git actions.

## Installation prerequisites

- Install Python 3 for your system
- Install pip3* for your system
- Install git for your system

*_Install pip instead of pip3, if pip3 does not exist for your OS_
## Installation

``pip3 install pygitscrum``*

*_Use pip instead of pip3, if pip3 does not exist_

## Upgrade

``pip3 install --upgrade pygitscrum``*

*_Use pip instead of pip3, if pip3 does not exist_

## Use

Just :

``pygitscrum`` to see the help message
